ut\_course\_catalog package
===========================

.. automodule:: ut_course_catalog
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

ut\_course\_catalog.common module
---------------------------------

.. automodule:: ut_course_catalog.common
   :members:
   :undoc-members:
   :show-inheritance:

ut\_course\_catalog.ja module
-----------------------------

.. automodule:: ut_course_catalog.ja
   :members:
   :undoc-members:
   :show-inheritance:
